@@ -1,9 +1,12 @@
 # Function for comparing full spatial ranges of two files
 compare_spatial_range <- function(
   file1,
-  file2
+  file2,
+  nc_file1 = NULL,
+  nc_file2 = NULL
 ) {
-  nc1 <- ncdf4::nc_open(file1)
+  if (!is.null(nc_file1)) nc1 <- nc_file1
+  else nc1 <- ncdf4::nc_open(file1)
 
   # Retrieve the grid and the dimensions of the existing outfile
   lon1 <- ncdf4::ncvar_get(nc1, "lon")
@@ -14,9 +17,10 @@ compare_spatial_range <- function(
   ny1 <- lat1[2] - lat1[1]
 
   # Close the file
-  ncdf4::nc_close(nc1)
+  if (is.null(nc_file1)) ncdf4::nc_close(nc1)
 
-  nc2 <- ncdf4::nc_open(file2)
+  if (!is.null(nc_file2)) nc2 <- nc_file2
+  else nc2 <- ncdf4::nc_open(file2)
 
   # Retrieve the grid and the dimensions of the existing outfile
   lon2 <- ncdf4::ncvar_get(nc2, "lon")
@@ -27,7 +31,7 @@ compare_spatial_range <- function(
   ny2 <- lat2[2] - lat2[1]
 
   # Close the file
-  ncdf4::nc_close(nc2)
+  if (is.null(nc_file2)) ncdf4::nc_close(nc2)
 
   return(
     lon1_range[1] == lon2_range[1] &&
